/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "cursorcolordialog.h"

CursorColorDialog::CursorColorDialog(QWidget *parent)
    : QDialog(parent)
{
    QLabel *selectColorLabel = new QLabel(tr("Select cursor color:"), this);
    QPushButton *blackCursorButton = new QPushButton(this);
    QPushButton *whiteCursorButton = new QPushButton(this);
    QGridLayout *layout = new QGridLayout;

    QPalette palette;

    palette.setColor(QPalette::Button, Qt::black);

    blackCursorButton->setAutoFillBackground(true);
    blackCursorButton->setFlat(true);
    blackCursorButton->setPalette(palette);

    palette.setColor(QPalette::Button, Qt::white);

    whiteCursorButton->setAutoFillBackground(true);
    whiteCursorButton->setFlat(true);
    whiteCursorButton->setPalette(palette);

    layout->addWidget(selectColorLabel);
    layout->addWidget(blackCursorButton);
    layout->addWidget(whiteCursorButton);

    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setLayout(layout);
    setBackgroundRole(QPalette::Dark);
    setAutoFillBackground(true);
    setWindowTitle(tr("Cursor Color"));
    setMinimumWidth(180);
    adjustSize();
    setModal(true);

    connect(blackCursorButton, SIGNAL(clicked()), this, SLOT(blackCursorColor()));
    connect(whiteCursorButton, SIGNAL(clicked()), this, SLOT(whiteCursorColor()));
}

void CursorColorDialog::blackCursorColor()
{
    blackColor = true;
    colorChanged();
}

void CursorColorDialog::whiteCursorColor()
{
    blackColor = false;
    colorChanged();
}

bool CursorColorDialog::colorIsBlack()
{
    return blackColor;
}
