/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "distmethoddialog.h"

DistMethodDialog::DistMethodDialog(QWidget *parent)
    : QDialog(parent)
{
    oneMeasuredDist = new QRadioButton(tr("One measured distance"), this);
    twoMeasuredDist = new QRadioButton(tr("Vertical and horizontal distance"), this);

    QImage noDistImage("images/noDist.png");

    distanceImageLabel = new QLabel(this);
    distanceImageLabel->setMinimumSize(81, 64);
    distanceImageLabel->setPixmap(QPixmap::fromImage(noDistImage));

    okButton = new QPushButton(tr("Ok"), this);
    okButton->setEnabled(false);

    QVBoxLayout *radioButtonsLayout = new QVBoxLayout;
    QGridLayout *distLayout = new QGridLayout;

    radioButtonsLayout->addWidget(oneMeasuredDist);
    radioButtonsLayout->addWidget(twoMeasuredDist);

    distLayout->addLayout(radioButtonsLayout, 0, 0);
    distLayout->addWidget(distanceImageLabel, 0, 1);
    distLayout->addWidget(okButton, 1, 1);

    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setWindowTitle(tr("Select the Method:"));
    setLayout(distLayout);
    setModal(true);

    connect(oneMeasuredDist, SIGNAL(clicked()), this, SLOT(changeImage()));
    connect(twoMeasuredDist, SIGNAL(clicked()), this, SLOT(changeImage()));
}

void DistMethodDialog::changeImage()
{
    okButton->setEnabled(true);

    if(oneMeasuredDist->isChecked())
    {
        QImage oneDistImage("images/oneDist.png");
        distanceImageLabel->setPixmap(QPixmap::fromImage(oneDistImage));
        method = 1;
    }
    else
    {
        QImage twoDistImage("images/twoDist.png");
        distanceImageLabel->setPixmap(QPixmap::fromImage(twoDistImage));
        method = 2;
    }
}

QPushButton* DistMethodDialog::getOkButton()
{
    return okButton;
}

int DistMethodDialog::getMethod()
{
    return method;
}
